%define duodir duo_unix-1.12.1
%define baseversion 1.12.1

%global moduletype contrib
%global modulename authlogin_duo

# Disable by default as the tests require root and write to /etc/pam.d
%bcond_with dotests 

Name:           duo_unix
Version:        1.12.1
Release:        1 
Summary:        Duo two-factor authentication for UNIX systems

License:        GPLv2
URL:            https://www.duosecurity.com/
Source0:        https://github.com/duosecurity/duo_unix/archive/refs/tags/%{name}-%{version}.tar.gz 
BuildArch:      ppc 

Suggests:       %{name}-doc = %{version}-%{release}

BuildRequires:  bzip2 >= 1.0.8-2
BuildRequires:  gcc >= 10.3.0
BuildRequires:  make
#BuildRequires:  openssl-devel
#BuildRequires:  pam-devel
BuildRequires:  zlib-devel >= 1.2.13-1
BuildRequires:  pkgconfig

%if %{with dotests}
BuildRequires:  python3.9 >= 3.9.17
%endif

# The third-party Duo package provided by the vendor ships pam_duo in the
# duo_unix package; we recommend the subpackage here to avoid lockout issues
# for systems accidentally being upgraded from the vendor package to this one
# See RHBZ#2134160 for more details.
Recommends:     pam_duo = %{version}-%{release}

%description
Duo provides simple two-factor authentication as a service via:

    1.  Phone callback
    2.  SMS-delivered one-time passcode
    3.  Duo mobile app to generate one-time passcode
    4.  Duo mobile app for smartphone push authentication
    5.  Duo hardware token to generate one-time passcode

This package allows an admin (or ordinary user) to quickly add Duo
authentication to any UNIX login without setting up secondary user
accounts, directory synchronization, servers, or hardware.

%package        doc
Summary:        Documentation and license files for %{name}
BuildArch:      noarch

%description    doc
Documentation and license files for %{name}

#%package -n     pam_duo
#Summary:        A PAM module for duo authentication
#Suggests:       %{name}-doc = %{version}-%{release}
#
#%description -n pam_duo
#A PAM module for duo authentication

%package        devel
Summary:        Development files and documentation for duo_unix
Requires:       %{name} = %{version}-%{release}
#Requires:       pam_duo = %{version}-%{release}

%description    devel
Development files and documentation for duo_unix


%prep
%setup -q -n %{name}-%{name}-%{version}

%build
export PATH=/opt/freeware/bin:$PATH
export OBJECT_MODE=64
export CC="/opt/freeware/bin/gcc -maix64 -O2" 
export LDFLAGS="-L/opt/freeware/lib64 -L/opt/freeware/lib -Wl,-blibpath:/opt/freeware/libexec64/sudo:/opt/freeware/libexec/sudo:/opt/freeware/lib64:/opt/freeware/lib:/usr/lib64:/usr/lib:/lib"


./bootstrap
./configure \
  --prefix=%{_prefix}\
  --sbindir=%{_prefix}/sbin \
  --mandir=%{_mandir} \
  --libexecdir=%{_libexecdir}64 \
  --docdir=%{_datadir}/doc/%{name}-%{version} \
  --libdir=%{_libdir}64 \
  --with-pam=%{_libdir}/security \
  --sysconfdir=%{_sysconfdir}/duo \
  --includedir=%{_includedir}/duo

gmake 
#gmake -C pam_duo 

%install
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}

export OBJECT_MODE=64
export PKG_CONFIG_PATH=/opt/freeware/lib64/pkgconfig
gmake install DESTDIR="${RPM_BUILD_ROOT}"
gmake install -C pam_duo DESTDIR="${RPM_BUILD_ROOT}"

chmod 0755 ${RPM_BUILD_ROOT}%{_sbindir}/*


%check
%if %{with dotests}
%endif
%clean

[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}

%files
%license LICENSE
%dir %{_sysconfdir}/duo
# This generates a non-readable rpmlint error, but this permission set is
# required for security. The Duo secrets are set in this file and allowing
# broader access risks exposing the secrets to other users on the system.
# sshd is the owner here since that user will run login_duo for SSH connections
# (the typical case) and this allows read access if capabilities aren't
# correctly set.
%attr(0600, sshd, root) %config(noreplace) %{_sysconfdir}/duo/login_duo.conf
%attr(0755, root, root) %{_sbindir}/login_duo
# This will generate no-manual-page-for-binary but Duo does not provide any
# manual page. This is intended to be run when seeking support from Duo.
%{_sbindir}/duo_unix_support.sh
%{_mandir}/man8/login_duo.8*
#%files -n pam_duo
#%license LICENSE
#%dir %{_sysconfdir}/duo
%dir %{_libdir}/security
%{_libdir}/security/pam_duo.a
# This generates a non-readable rpmlint error, but this permission set is
# required for security. The Duo secrets are set in this file and allowing
# broader access risks exposing the secrets to other users on the system.
%config(noreplace) %attr(0600, root, root) %{_sysconfdir}/duo/pam_duo.conf
%{_mandir}/man8/pam_duo.*

%files doc
%license LICENSE
%doc README.md AUTHORS CHANGES
%doc %{_defaultdocdir}/%{name}

%files devel
%exclude %{_includedir}/duo/unity.h
%exclude %{_includedir}/duo/duo_private.h
%exclude %{_includedir}/duo/common_ini_test.h
%dir %{_includedir}/duo
%{_includedir}/duo/duo.h
%{_includedir}/duo/util.h
%{_includedir}/duo/shell.h
%{_libdir}64/pkgconfig/libduo.pc
%{_mandir}/man3/duo.3*


%changelog
* Fri Sep 8 2023 Sangeetha Bandi<sanbandi@in.ibm.com> -  1.12.1-1
- First port to AIX 

